









' Content voting buttons.








' entry point of detailsScreen
function Init()
    m.mainScene = m.top.getScene()
    ' Get the Content Voting flag.
    m.contentVoting = GetValueFromManifest("CONTENT_VOTING")
    m.currentVote = "no vote"
    ' observe "visible" so we can know when DetailsScreen change visibility
    m.top.ObserveField("visible", "OnVisibleChange")
    ' observe "itemFocused" so we can know when another item gets in focus
    m.top.ObserveField("itemFocused", "OnItemFocusedChanged")
    ' observe "buttonFocused" so we can know when a button is focused.
    m.top.ObserveField("buttonFocused", "OnButtonFocused")
    ' save a references to the DetailsScreen child components in the m variable
    ' so we can access them easily from other functions
    ' details buttons.
    m.detailsButtons = m.top.FindNode("detailsButtons")
    SetButtonFont()
    ' poster.
    m.poster = m.top.FindNode("poster")
    ' title label.
    m.titleLabel = m.top.FindNode("titleLabel")
    setFont(m.titleLabel, [
        "GothamBoldDarkBlue"
    ])
    ' description label.
    m.description = m.top.FindNode("descriptionLabel")
    setFont(m.description, [
        "GothamDarkBlue18"
    ])
    ' extras label.
    m.extrasLabel = m.top.FindNode("extrasLabel")
    setFont(m.extrasLabel, [
        "GothamDarkBlue12"
        "GenericDingbatsSmall"
    ])
    ' time remaining label.
    m.timeremainingLabel = m.top.FindNode("timeremainingLabel")
    setFont(m.timeremainingLabel, [
        "GothamDarkBlue12"
    ])
    m.timeremainingLabel.visible = false
    ' voting label.
    m.votingLabel = m.top.FindNode("votingLabel")
    setFont(m.votingLabel, [
        "GothamWhite12"
    ])
    m.votingLabel.visible = false
    ' voting timer.
    m.votingTimer = m.top.FindNode("votingTimer")
    m.buttonIndex = 0
end function

sub OnVisibleChange() ' invoked when DetailsScreen visibility is changed
    if m.top.visible = true
        position = [
            0.0
        ]
        remainingStr = []
        feedItem = GetFeedItemFromContent(m.top.content, m.top.itemFocused)
        ' Don't check for remaining time if the content object is a Series.
        if ContentIsSeries(feedItem) = false
            ' Check if the video can be continued.
            videoCanBeContinued = ContentCanBeContinued(m.top.content, position, remainingStr)
            ' If the video can be continued, update the button group for Continue/Restart.
            if videoCanBeContinued = true
                SetDetailButtons([
                    "Continue"
                    "Restart"
                ], 0)
                m.timeremainingLabel.text = "<GothamDarkBlue12> " + remainingStr[0] + "</GothamDarkBlue12>"
                m.timeremainingLabel.visible = true
            else
                ' Update the button group for Play.
                SetDetailButtons([
                    "Play"
                ], 0)
                m.timeremainingLabel.visible = false
            end if
        end if
        ' set focus for buttons list when DetailsScreen become visible
        m.detailsButtons.SetFocus(true)
    end if
end sub

'''''''''
' OnButtonFocused: Event handler - Invoked when a button is focused.
' 
' @param {object} event
'''''''''
sub OnButtonFocused(event as object)
    m.buttonIndex = event.GetData()
end sub

'''''''''
' SetButtonFont: Set the font for the Details button group.
' 
' @return {dynamic}
'''''''''
function SetButtonFont() as void
    m.detailsTextfont = CreateObject("roSGNode", "Font")
    m.detailsTextfont.uri = "pkg:/fonts/Gotham-Medium.otf"
    m.detailsTextfont.size = 12
    m.detailsButtons.textFont = m.detailsTextfont
    m.detailsFocusedTextfont = CreateObject("roSGNode", "Font")
    m.detailsFocusedTextfont.uri = "pkg:/fonts/Gotham-Medium.otf"
    m.detailsFocusedTextfont.size = 12
    m.detailsButtons.focusedTextFont = m.detailsFocusedTextfont
end function

'''''''''
' GetGroupButtonText: Get the group button text.
' 
' @param {integer} I: _index - index of the button to get.
' @return {string} - returns the button text if the index is valid.
'''''''''
function GetGroupButtonText(_index as integer) as string
    if _index < m.detailsButtons.getChildCount()
        button = m.detailsButtons.getChild(_index)
        return button.text
    else
        return ""
    end if
end function

'''''''''
' AddButtonToGroup: Adds a button to the button group.
' 
' @param {dynamic} I: _buttonText - the text of the button.
'''''''''
function AddButtonToGroup(_buttonText) as void
    buttonImages = {
        "Play": "pkg:/images/play.png"
        "Play all": "pkg:/images/playall.png"
        "Restart": "pkg:/images/restart.png"
        "Continue": "pkg:/images/resume.png"
        "Episodes": "pkg:/images/episodes.png"
        "Like/Dislike": "pkg:/images/no_vote.png"
        "Liked": "pkg:/images/like.png"
        "Disliked": "pkg:/images/dislike.png"
    }
    button = CreateObject("roSGNode", "Button")
    button.text = _buttonText
    button.focusedIconUri = buttonImages[_buttonText]
    button.textFont = m.detailsTextfont
    button.focusedTextFont = m.detailsFocusedTextfont
    m.detailsButtons.AppendChild(button)
end function

'''''''''
' SetDetailButtons: Sets the button set the for the Details screen.
' 
' @param {object} _buttons - _buttons - array of button text.
' @param {integer} _index - index of the focused button.
' @return {dynamic}
'''''''''
function SetDetailButtons(_buttons as object, _index as integer) as void
    ' Get the current child buttons.
    buttonChildren = m.detailsButtons.getChildren(- 1, 0)
    ' Remove the prior buttons from the Group if there are any,
    if buttonChildren.Count() > 0
        m.detailsButtons.removeChildren(buttonChildren)
    end if
    ' For each button in the button array, add a child button node to the group.
    for each buttonText in _buttons
        AddButtonToGroup(buttonText)
    end for
    ' Add the Like/Dislike button if required.
    if m.contentVoting = "true"
        vote = []
        feedItem = GetFeedItemFromContent(m.top.content, m.top.itemFocused)
        if VoteHasBeenCast(feedItem.id, vote) = true
            AddButtonToGroup(vote[0] + "d")
        else
            AddButtonToGroup("Like/Dislike")
        end if
    end if
    m.detailsButtons.iconUri = ""
end function

sub SetDetailsContent(content as Object)
    ' Get the Bookmarks object.
    if content.mediaType = "series"
        m.contentBookmark = SmartBookmark()
    else
        m.contentBookmark = Bookmark()
    end if
    ' Title.
    m.titleLabel.text = "<GothamBoldDarkBlue>" + content.title + "</GothamBoldDarkBlue>"
    ' Content description.
    m.description.text = "<GothamDarkBlue18>" + content.description + "</GothamDarkBlue18>"
    ' Add genres, release date, etc.
    m.extrasLabel.text = "<GothamDarkBlue12>" + Left(content.releaseDate, 4) + " </GothamDarkBlue12>"
    m.extrasLabel.text += "<GenericDingbatsSmall>" + chr(62504) + " </GenericDingbatsSmall>"
    if content.genres <> invalid
        genreCount = content.genres.Count()
        for each genre in content.genres
            m.extrasLabel.text += "<GothamDarkBlue12>"
            m.extrasLabel.text += genre
            m.extrasLabel.text += " </GothamDarkBlue12>"
            if genreCount >= 1
                m.extrasLabel.text += "<GenericDingbatsSmall>" + chr(62504) + " </GenericDingbatsSmall>"
                genreCount -= 1
            end if
        end for
    end if
    if content.rating <> invalid and content.rating <> ""
        m.extrasLabel.text += "<GothamDarkBlue12>"
        m.extrasLabel.text += " " + content.rating
        m.extrasLabel.text += " </GothamDarkBlue12>"
        m.extrasLabel.text += "<GenericDingbatsSmall>" + chr(62504) + " </GenericDingbatsSmall>"
    end if
    ' If the media type is NOT a "series", show the duration.  Otherwise, show the number of Seasons/Episodes.
    if content.mediaType <> "series"
        if content.length <> invalid and content.length <> 0
            m.extrasLabel.text += "<GothamDarkBlue12>"
            m.extrasLabel.text += " " + GetTime(content.length)
            m.extrasLabel.text += "</GothamDarkBlue12>"
        end if
    else
        m.extrasLabel.text += "<GothamDarkBlue12>"
        if content.hasSeasons = true
            m.extrasLabel.text += content.numSeasons.toStr() + " Seasons "
        end if
        m.extrasLabel.text += content.numEpisodes.toStr() + " Episodes"
        m.extrasLabel.text += "</GothamDarkBlue12>"
    end if
    if content.mediaType = "series"
        m.detailsButtons.minWidth = "150.0"
        ' buttons for series DetailsScreen.
        SetDetailButtons([
            "Play all"
            "Episodes"
        ], m.detailsButtons.buttonFocused)
    else
        position = [
            0.0
        ]
        remainingStr = []
        ' buttons for content DetailsScreen.
        if ContentCanBeContinued(m.top.content, position, remainingStr) = true
            m.detailsButtons.minWidth = "150.0"
            SetDetailButtons([
                "Continue"
                "Restart"
            ], m.detailsButtons.buttonFocused)
            m.timeremainingLabel.text = "<GothamDarkBlue12> " + remainingStr[0] + "</GothamDarkBlue12>"
            m.timeremainingLabel.visible = true
        else
            m.detailsButtons.minWidth = "150.0"
            SetDetailButtons([
                "Play"
            ], m.detailsButtons.buttonFocused)
        end if
    end if
    ' Display the content thumbnail as the background if requested.
    if m.global.useThumbnailBackground = true
        SetBackgroundImage(content)
    end if
end sub

sub OnJumpToItem() ' invoked when jumpToItem field is populated
    content = m.top.content
    ' check if jumpToItem field has valid value
    ' it should be set within interval from 0 to content.Getchildcount()
    if content <> invalid and m.top.jumpToItem >= 0 and content.GetChildCount() > m.top.jumpToItem
        m.top.itemFocused = m.top.jumpToItem
    else if content <> invalid and content.mediaType = "episode" and m.top.jumpToItem >= 0
        m.top.itemFocused = m.top.jumpToItem
    end if
end sub

sub OnItemFocusedChanged(event as Object)
    ' Get the position in the Grid of the selected item.
    focusedItem = event.GetData()
    content = m.top.content.GetChild(focusedItem) ' get metadata of focused item
    SetDetailsContent(content) ' populate DetailsScreen with item metadata
end sub

' The OnKeyEvent() function receives remote control key events
function OnkeyEvent(key as String, press as Boolean) as Boolean
    result = false
    if press
        ' Get the number of buttons in the button group.
        numberOfButtonsInGroup = m.detailsButtons.GetChildCount()
        ' handle "back" button keypress.
        if key = "back"
            SetBackgroundImage(invalid)
            ' handle "left" button keypress
        else if key = "left"
            ' Get the number of the details buttons.
            ' There must be more than one button in the group to process a left key press.
            if numberOfButtonsInGroup > 1
                ' If the index is greater than the number of buttons, process the left key press.
                if m.buttonIndex > 0
                    m.detailsButtons.focusButton = m.buttonIndex - 1
                    result = true
                end if
            end if
            ' handle "right" button keypress
        else if key = "right"
            ' Get the number of the details buttons.
            ' There must be more than one button in the group to process a right key press.
            if numberOfButtonsInGroup > 1
                ' If the index is less than the number of buttons, process the right key press.
                if m.buttonIndex < numberOfButtonsInGroup - 1
                    m.detailsButtons.focusButton = m.buttonIndex + 1
                    result = true
                end if
            end if
        else if key = "options"
            ' Get the Content object.
            content = m.top.content.GetChild(m.top.itemFocused)
            message = []
            ' Check for a long description first.  Otherwise, use the short description.
            if content.longDescription <> invalid
                message.Push(content.longDescription)
            else if content.shortDescription <> invalid
                message.Push(content.shortDescription)
            end if
            if content.Actors <> invalid and content.Actors.Count() > 0
                for each actor in content.Actors
                    message.Push("Actor: " + actor)
                end for
            end if
            if content.Hosts <> invalid and content.Hosts.Count() > 0
                for each host in content.Hosts
                    message.Push("Host: " + host)
                end for
            end if
            if content.Narrators <> invalid and content.Narrators.Count() > 0
                for each narrator in content.Narrators
                    message.Push("Narrator: " + narrator)
                end for
            end if
            if content.Directors <> invalid and content.Directors.Count() > 0
                for each director in content.Directors
                    message.Push("Director: " + director)
                end for
            end if
            if content.Producers <> invalid and content.Producers.Count() > 0
                for each producer in content.Producers
                    message.Push("Producer: " + producer)
                end for
            end if
            m.descriptionDialog = CreateMessageDialog(content.title, message, [
                "Ok"
            ])
            m.descriptionDialog.palette = CreateADialogPalette()
            ' observe the dialog's buttonSelected field to handle button selections
            m.descriptionDialog.observeFieldScoped("buttonSelected", "OkButtonSelected")
            ' display the dialog
            scene = m.top.getScene()
            scene.dialog = m.descriptionDialog
            result = true
        end if
    end if
    return result
end function

'''''''''
' OkButtonSelected: Handles Ok button click on the Description Dialog.
' 
'''''''''
sub OkButtonSelected()
    if m.descriptionDialog.buttonSelected = 0
        ' handle ok button here
        m.descriptionDialog.close = true
    end if
end sub

'''''''''
' SetBackgroundImage: Sets the background image for the Details screen.
' 
' @param {object} I: _content - the content item that contains the image.
' @return {dynamic}
'''''''''
function SetBackgroundImage(_content as object) as void
    if _content = invalid
        m.mainScene.backgrounduri = ""
    else
        m.mainScene.backgrounduri = _content.hdposterurl
    end if
end function

'''''''''
' ContentCanBeContinued: Determines if the vide content can be continued.
' 
' @param {object} I: _content - the video content node.
' @param {object} O: _position - the content playback position.
' @param {object} O: _remaining - time remaining string if the content can be continued.
' @return {boolean} - returns true if content can be continued.  Else, false.
'''''''''
function ContentCanBeContinued(_content as object, _position as object, _remaining as object) as boolean
    feedContent = GetFeedItemFromContent(_content, m.top.itemFocused)
    ' If the content is for a Series, disregard.
    if feedContent.mediaType = "series"
        return false
    end if
    contentBookmark = Bookmark()
    _position[0] = contentBookmark.GetLastVideoPosition(feedContent.id)
    _remaining[0] = GetTimeRemaining(feedContent.length, _position)
    return contentBookmark.VideoCanBeResumed(feedContent.id, _position)
end function'//# sourceMappingURL=./DetailsScreen.bs.map