' entry point of EpisodesScreen
function Init()    
    m.episodesList = m.top.FindNode("episodesList")
    ' Extras label.
    m.extrasLabel = m.top.FindNode("extrasLabel")
    setFont(m.extrasLabel, ["GothamDarkBlue12", "GenericDingbatsSmall"])
    ' Credits label.
    m.creditsLabel = m.top.FindNode("creditsLabel")
    setFont(m.creditsLabel, ["GothamDarkBlue12", "GenericDingbatsSmall"])

    ' voting label.
    m.votingLabel = m.top.FindNode("votingLabel")
    setFont(m.votingLabel, ["GothamWhite12"])
    m.votingLabel.visible = false

    ' voting timer.
    m.votingTimer = m.top.FindNode("votingTimer")

    ' observe "visible" so we can know when EpisodesScreen change visibility
    m.top.ObserveField("visible", "onVisibleChange")
    ' observe "itemSelected" so we can know which episode is selected
    m.episodesList.ObserveField("itemSelected", "OnEpisodeListItemSelected")
    m.top.ObserveField("content", "OnEpisodeContentChange")    

    ' Get the Content Voting flag.
    m.contentVoting = GetValueFromManifest("CONTENT_VOTING")

end function

sub onVisibleChange() ' invoked when Episodes screen becomes visible
    if m.top.visible = true
        m.episodesList.setFocus(true) ' set focus to the episodes list
    end if
end sub

sub OnEpisodeListItemSelected(event as Object) ' invoked when episode is selected
    itemSelected = event.GetData() ' index of selected item
    m.top.selectedItem = itemSelected    
end sub

sub OnJumpToItem(event as Object) ' invoked when "jumpToItem field is changed
    itemIndex = event.GetData()
    m.episodesList.jumpToItem = itemIndex ' navigate to the specified item
end sub

'''''''''
' SetSeriesCredits: Sets the Series Credits.
' 
' @param {object} I: _content - the Series content.
' @return {dynamic}
'''''''''
function SetSeriesCredits(_content as object)

    m.creditsLabel.text = ""

    if _content.actors <> invalid and _content.actors.Count() > 0
        m.creditsLabel.text += "<GenericDingbatsSmall>" + chr(62504) +" </GenericDingbatsSmall>"
        m.creditsLabel.text += "<GothamDarkBlue12>"
        m.creditsLabel.text += "Actors: "
        for each actor in _content.actors
            m.creditsLabel.text += actor + " "
        end for
        m.creditsLabel.text += "</GothamDarkBlue12>"
    end if

    if _content.directors <> invalid and _content.directors.Count() > 0
        m.creditsLabel.text += "<GenericDingbatsSmall>" + chr(62504) +" </GenericDingbatsSmall>"
        m.creditsLabel.text += "<GothamDarkBlue12>"
        m.creditsLabel.text += "Directors: "
        for each director in _content.directors
            m.creditsLabel.text += director + " "
        end for
        m.creditsLabel.text += "</GothamDarkBlue12>"
    end if

    if _content.narrators <> invalid and _content.narrators.Count() > 0
        m.creditsLabel.text += "<GenericDingbatsSmall>" + chr(62504) +" </GenericDingbatsSmall>"
        m.creditsLabel.text += "<GothamDarkBlue12>"
        m.creditsLabel.text += "Narrators: "
        for each narrator in _content.narrators
            m.creditsLabel.text += narrator + " "
        end for
        m.creditsLabel.text += "</GothamDarkBlue12>"
    end if

    if _content.producers <> invalid and _content.producers.Count() > 0
        m.creditsLabel.text += "<GenericDingbatsSmall>" + chr(62504) +" </GenericDingbatsSmall>"
        m.creditsLabel.text += "<GothamDarkBlue12>"
        m.creditsLabel.text += "Producers: "
        for each producer in _content.producers
            m.creditsLabel.text += producer + " "
        end for
        m.creditsLabel.text += "</GothamDarkBlue12>"
    end if

    if _content.hosts <> invalid and _content.hosts.Count() > 0
        m.creditsLabel.text += "<GenericDingbatsSmall>" + chr(62504) +" </GenericDingbatsSmall>"
        m.creditsLabel.text += "<GothamDarkBlue12>"
        m.creditsLabel.text += "Hosts: "
        for each host in _content.hosts
            m.creditsLabel.text += host + " "
        end for
        m.creditsLabel.text += "</GothamDarkBlue12>"
    end if

end function

'''''''''
' OnEpisodeContentChange: Called when the content is changed.
' 
'''''''''
sub OnEpisodeContentChange()
    content = m.top.content
    ' Get all of the series Episodes.
    episodes = content.GetChildren(-1, 0)
    ' Set the thumbnail of the first episode.
    m.top.FindNode("seriesThumbnail").uri = episodes[0].thumbnail
    ' Populate the list of Episodes in the MarkupList.
    m.episodesList.content = content

    m.extrasLabel.text = ""

    m.extrasLabel.text += "<GothamDarkBlue12>"
    m.extrasLabel.text += content.numEpisodes.toStr() + " Episodes"    
    m.extrasLabel.text += "</GothamDarkBlue12>"
    m.extrasLabel.text += "<GenericDingbatsSmall>" + chr(62504) +" </GenericDingbatsSmall>"

    if content.genres <> invalid
        genreCount= content.genres.Count()
        for each genre in content.genres
            m.extrasLabel.text += "<GothamDarkBlue12>"
            m.extrasLabel.text += genre
            m.extrasLabel.text += " </GothamDarkBlue12>"
            if genreCount >= 1
                m.extrasLabel.text += "<GenericDingbatsSmall>" + chr(62504) +" </GenericDingbatsSmall>"
                genreCount -= 1
            end if            
        end for
    end if

    SetSeriesCredits(content)
end sub

' The OnKeyEvent() function receives remote control key events
function OnKeyEvent(key as String, press as Boolean) as Boolean
    result = false

    if press
        ' Look for Options press to display full text.
        if key = "options"
            ' Get the Series object.
            series = m.top.content
            ' Get the Episodes attached to the Series.
            episodes = series.GetChildren(-1, 0)
            selectedEpisode = episodes[m.episodesList.itemFocused]
            description = []
            description.Push(selectedEpisode.longDescription)

            if selectedEpisode.Actors <> invalid and selectedEpisode.Actors.Count() > 0
                for each actor in selectedEpisode.Actors
                    description.Push("Actor: " + actor)                    
                end for
            end if

            if selectedEpisode.Hosts <> invalid and selectedEpisode.Hosts.Count() > 0
                for each host in selectedEpisode.Hosts
                    description.Push("Host: " + host)                    
                end for
            end if

            if selectedEpisode.Narrators <> invalid and selectedEpisode.Narrators.Count() > 0
                for each narrator in selectedEpisode.Narrators
                    description.Push("Narrator: " + narrator)                    
                end for
            end if

            if selectedEpisode.Directors <> invalid and selectedEpisode.Directors.Count() > 0
                for each director in selectedEpisode.Directors
                    description.Push("Director: " + director)                    
                end for
            end if

            if selectedEpisode.Producers <> invalid and selectedEpisode.Producers.Count() > 0
                for each producer in selectedEpisode.Producers
                    description.Push("Producer: " + producer)                    
                end for
            end if

            ' Set the dialog button(s).
            if m.contentVoting = "" OR m.contentVoting = "false"
                m.descriptionDialog = CreateMessageDialog(episodes[m.episodesList.itemFocused].title, description, ["Ok"])
            else
                m.descriptionDialog = CreateMessageDialog(episodes[m.episodesList.itemFocused].title, description, ["Like", "Dislike"])
            end if

            m.descriptionDialog.palette = CreateADialogPalette()
            ' observe the dialog's buttonSelected field to handle button selections
            m.descriptionDialog.observeFieldScoped("buttonSelected", "onOptionVoteButtonSelected")
        
            ' display the dialog
            scene = m.top.getScene()
            scene.dialog = m.descriptionDialog                
            result = true

        end if
    end if
    return result
end function

'''''''''
' onOptionVoteButtonSelected: Handles vote button click on the Description Dialog.
' 
'''''''''
sub onOptionVoteButtonSelected()
    m.descriptionDialog.close = true        

    if m.contentVoting = "true"
        episodes = m.top.content.GetChildren(-1, 0)
        selectedEpisode = episodes[m.episodesList.itemFocused]
        VoteForContent(selectedEpisode.id, m.descriptionDialog.buttons[m.descriptionDialog.buttonSelected], m.top)
    end if
end sub'//# sourceMappingURL=./EpisodesOnlyScreen.brs.map