' entry point of GridScreen.
' Note that we need to iport this file in GridScreen.xml using relative path.
sub Init()
    m.mainScene = m.top.getScene()

    ApplyOverhangOptions()

    m.rowList = m.top.FindNode("rowList")
    m.rowList.SetFocus(true)

    ' observe visible field so we can see GridScreen change visibility.
    m.top.ObserveField("visible", "OnVisibleChange")

    ' label with item title.
    m.titleLabel = m.top.FindNode("titleLabel")
    setFont(m.titleLabel, ["GothamBoldDarkBlue"])

    ' label with item description.
    m.descriptionLabel = m.top.FindNode("descriptionLabel")
    setFont(m.descriptionLabel, ["NordicaClassicLightItalic"])

    ' content thumbnail.
    m.contentThumbnail = m.top.FindNode("contentThumbnail")

    ' extras label.
    m.extrasLabel = m.top.FindNode("extrasLabel")
    setFont(m.extrasLabel, ["GothamDarkBlue12", "GenericDingbatsSmall"])

    ' observe rowItemFocused so we can know when another item of rowList will be focused.
    m.rowList.ObserveField("rowItemFocused", "OnItemFocused")
        
end sub

sub OnVisibleChange()
    if m.top.visible = true
        m.rowList.SetFocus(true)    ' set focus to RowList if GridScreen is visible.
    end if
end sub

sub OnItemFocused() ' invoked when another item is focused.
    focusedIndex = m.rowList.rowItemFocused ' get position of focused item.
    row = m.rowList.content.GetChild(focusedIndex[0])   ' get all items of row.
    item = row.GetChild(focusedIndex[1])    ' get focused item.

    if item <> invalid
        ApplyManifestOptions(item)

        ' update title label with title of focused item.        
        m.titleLabel.text = "<GothamBoldDarkBlue>" + item.title + "</GothamBoldDarkBlue>"

        ' update description label with description of focused item.
        m.descriptionLabel.text = "<NordicaClassicLightItalic>" + item.shortDescription + "</NordicaClassicLightItalic>"

        ' Add genres, release date, etc.
        m.extrasLabel.text = "<GothamDarkBlue12>" + Left(item.releaseDate, 4) + " </GothamDarkBlue12>"
        m.extrasLabel.text += "<GenericDingbatsSmall>" + chr(62504) +" </GenericDingbatsSmall>"

        if item.genres <> invalid
            for each genre in item.genres
                m.extrasLabel.text += "<GothamDarkBlue12>"
                m.extrasLabel.text += genre
                m.extrasLabel.text += " </GothamDarkBlue12>"
                m.extrasLabel.text += "<GenericDingbatsSmall>" + chr(62504) +" </GenericDingbatsSmall>"
            end for
        end if
        
        if item.rating <> invalid and item.rating <> ""
            m.extrasLabel.text += "<GothamDarkBlue12>"
            m.extrasLabel.text += " " + item.rating
            m.extrasLabel.text += " </GothamDarkBlue12>"
            m.extrasLabel.text += "<GenericDingbatsSmall>" + chr(62504) +" </GenericDingbatsSmall>"
        end if

        ' If the media type is NOT a "series", show the duration.  Otherwise, show the number of Seasons/Episodes.
        if item.mediaType <> "series"
            if item.length <> invalid and item.length <> 0
                m.extrasLabel.text += "<GothamDarkBlue12>"
                m.extrasLabel.text += " " + GetTime(item.length)
                m.extrasLabel.text += "</GothamDarkBlue12>"
            end if
        else
            m.extrasLabel.text += "<GothamDarkBlue12>"
            if item.hasSeasons = true
                m.extrasLabel.text += item.numSeasons.toStr() + " Seasons "
            end if

            m.extrasLabel.text += item.numEpisodes.toStr() + " Episodes"
            m.extrasLabel.text += "</GothamDarkBlue12>"
        end if

        m.contentThumbnail.uri = item.hdposterurl
    else
        m.titleLabel.text = "WARNING: Missing content."
        m.descriptionLabel.text = "Content for this category has not been defined."
        m.extrasLabel.text = ""  
        m.contentThumbnail.uri = ""      
    end if

end sub

'''''''''
' ApplyManifestOptions: Apply any manifest options.
' 
' @param {object} I: _item - the selected grid item.
' @return {dynamic}
'''''''''
function ApplyManifestOptions(_item as object)
    ' Check for dynamic background assignment.
    if m.global.useThumbnailBackground = true and _item <> invalid
        m.mainScene.backgrounduri = _item.hdposterurl        
    end if

end function

'''''''''
' ApplyOverhangOptions: Applies options to the overhang component.
' 
' @return {dynamic}
'''''''''
function ApplyOverhangOptions()
    overhang = m.top.FindNode("overhang")
    
    hideGridThumbnail = GetValueFromManifest("HIDE_GRID_THUMBNAIL")
    if hideGridThumbnail <> invalid and hideGridThumbnail = "true"
        ' Hide the thumbnail poster.
        m.top.FindNode("contentThumbnail").visible = false
        ' Expand the overhang scale if necessary.
        if overhang <> invalid
            overhang.scale = "[1.0, 1.0]"
        end if
    end if
    
    if overhang <> invalid
        clock = GetValueFromManifest("OVERHANG_CLOCK")
        if clock = "false"
            overhang.showClock = false
        end if

        options = GetValueFromManifest("OVERHANG_OPTIONS")
        if options = "false"
            overhang.showOtions = false
            overhang.optionsAvailable = false
        end if

        search = GetValueFromManifest("ALLOW_CHANNEL_SEARCH")
        if search = "true"
            overhang.optionsText = "Search"
        end if
    end if

end function
'//# sourceMappingURL=./GridScreen.brs.map