'import "pkg:/components/UILogic/SearchScreenLogic.bs"
'import "pkg:/components/UILogic/DetailsScreenLogic.bs"
'import "pkg:/components/UILogic/LoginStatusLogic.bs"
'import "pkg:/components/UILogic/BookmarkLogic.bs"
'import "pkg:/components/UILogic/AccessTokenLogic.bs"
'import "pkg:/components/UILogic/ScreenStackLogic.bs"
'import "pkg:/source/utils.bs"

sub Init()
    ' observe "visible" so we can know when DetailsScreen change visibility
    m.top.ObserveField("visible", "OnVisibleChange")
    ' Save the searchList object.
    m.searchList = m.top.findNode("searchList")
    m.searchList.drawFocusFeedback = false
    m.searchList.ObserveField("itemSelected", "OnSearchItemSelected")
    ' Sve the searchResults label.
    m.searchResults = m.top.findNode("searchResults")
    m.searchResults.text = "Your search returned no items"
    ' Observe 'text' so we know when the user enters some text.
    m.miniKeyboard = m.top.findNode("searchKeyboard")
    m.miniKeyboard.ObserveField("text", "OnTextChanged")
    m.miniKeyboard.setFocus(true)
    ' Define a String object for use later.
    m.stringObject = CreateObject("roString")
end sub

sub OnVisibleChange() ' invoked when SearchScreen visibility is changed
    if m.top.visible = true
        ' Force a rebuild of the search list with the current search text.
        OnTextChanged()
        ' Focus the last selected search item.
        m.searchList.jumpToItem = m.itemSelected
        m.searchList.setFocus(true)
    end if
end sub

'''''''''
' OnSearchItemSelected: Event handler - handles search item selection.
' 
' @param {object} event
'''''''''
sub OnSearchItemSelected(event as Object) ' invoked when search item is selected
    m.itemSelected = event.GetData() ' index of selected item
    searchContent = m.searchList.content.getChild(m.itemSelected)
    contentNode = CreateObject("roSGNode", "ContentNode")
    contentNode.AppendChild(searchContent)
    HandleSearchSelection(contentNode)
end sub

'''''''''
' OnTextChanged: Event handler - Handles text change event for the mini keyboard.
' 
' @return {dynamic}
'''''''''
function OnTextChanged()
    ' Get the text input.
    textInput = m.miniKeyboard.text
    if textInput = ""
        m.searchList.content = invalid
        m.searchResults.text = "Your search did not return any items."
    else
        searchContent = []
        for each indexEntry in m.global.ContentIndex
            foundContent = false
            ' Search within Title.
            m.stringObject.SetString(LCase(indexEntry.title))
            if m.stringObject.Instr(LCase(textInput)) <> - 1
                foundContent = true
            else
                ' Search within Description.
                m.stringObject.SetString(LCase(indexEntry.desc))
                if m.stringObject.Instr(LCase(textInput)) <> - 1
                    foundContent = true
                end if
            end if
            if foundContent = true
                item = FindContentWithinGrid(indexEntry.id)
                if item <> invalid
                    searchContent.Push(item)
                end if
            end if
        end for
        ' If we found search items, set the search list to reflect them.
        if searchContent.Count() > 0
            m.searchResults.text = "Your search returned " + searchContent.Count().toStr() + " items."
            m.searchList.content = SearchContentListToSimpleNode(searchContent)
            m.searchList.jumpToItem = 0
        else
            m.searchList.content = ""
            m.searchResults.text = "Your search returned no items"
        end if
    end if
end function

'''''''''
' FindContentWithinGrid: Finds the requested content with the Grid object.
' 
' @param {string} I: _id - content ID of the requested object.
' @return {object} - returns the grid item.
'''''''''
function FindContentWithinGrid(_id as string) as object
    gridContent = m.top.content.getChildren(- 1, 0)
    for each gridRow in gridContent
        if gridRow.getChildCount() > 0
            for each gridColumn in gridRow.getChildren(- 1, 0)
                if gridColumn.id = _id
                    return gridColumn.clone(true)
                end if
            end for
        end if
    end for
    return invalid
end function

'''''''''
' OnKeyEvent: Event Handler: Handles remote key presses.
' 
' @param {string} I: key - the key that as pressed.
' @param {boolean} I: press - flag to indicate a key press.
' @return {boolean} - returns true if this code handles the key press.
'''''''''
function OnKeyEvent(key as String, press as Boolean) as Boolean
    handled = false
    if press = true
        ' RIGHT key press.
        if key = "right"
            m.searchList.SetFocus(true)
            m.searchList.drawFocusFeedback = true
            handled = true
        end if
        ' LEFT key press.
        if m.searchList.hasFocus() = true and key = "left"
            m.miniKeyboard.setFocus(true)
            m.searchList.drawFocusFeedback = false
            handled = true
        end if
        ' OPTIONS key press.
        if m.searchList.hasFocus() = true and key = "options"
            message = []
            searchContent = m.searchList.content.getChild(m.searchList.itemFocused)
            message.push(searchContent.longDescription)
            m.descriptionDialog = CreateMessageDialog(searchContent.title, message, [
                "Ok"
            ])
            m.descriptionDialog.palette = CreateADialogPalette()
            ' observe the dialog's buttonSelected field to handle button selections
            m.descriptionDialog.observeFieldScoped("buttonSelected", "onOptionOkButtonSelected")
            ' display the dialog
            scene = m.top.getScene()
            scene.dialog = m.descriptionDialog
            handled = true
        end if
    end if
    return handled
end function

'''''''''
' onOptionOkButtonSelected: Event handler - Handles OK button press for Options dialog.
' 
'''''''''
sub onOptionOkButtonSelected()
    if m.descriptionDialog.buttonSelected = 0
        ' handle ok button here
        m.descriptionDialog.close = true
    end if
end sub

'''''''''
' HandleSearchSelection: Handles the selection of a Search item.
' 
' @param {object} I: content - the Search content to process.
'''''''''
sub HandleSearchSelection(content as Object)
    ' Get the associated feed item.
    feedContent = GetFeedItemFromContent(content, 0)
    seriesFlag = false
    ' If search content is a Series, default to play all.
    if feedContent.mediaType = "series"
        feedContent.addFields({
            "PlayAll": true
        })
        seriesFlag = true
    end if
    if m.global.useSubscriptions <> true
        ShowVideoScreen(feedContent, 0, seriesFlag)
    else
        CheckSubscriptionAndStartPlayback(feedContent, 0, seriesFlag)
    end if
end sub'//# sourceMappingURL=./SearchScreen.bs.map