'''''''''
' LoadChannelContent: Loads the channel content by spawning a task to iterate the feed file.
' 
'''''''''
sub LoadChannelContent()
    m.ContentTask = CreateObject("roSGNode", "MainLoaderTask") ' create task for retrieving channel feed.
    ' observe content so we can know when the feed content will be parsed.
    m.contentTask.ObserveField("content", "OnMainContentLoaded")
    m.contentTask.control = "run" ' GetContent(see MainLoaderTask.brs) method is executed.
    m.loadingIndicator.visible = true ' show loading indicator while content is loading.
end sub

'''''''''
' OnMainContentLoaded: Event: called after the content feed has been loaded.
' 
'''''''''
sub OnMainContentLoaded() ' invoked when content has been parsed and is ready to use.
    m.GridScreen.SetFocus(true) ' set focus to the GridScreen.
    m.loadingIndicator.visible = false ' hide loading indicator because content was retrieved.
    m.GridScreen.content = m.contentTask.content ' populate GridScreen with content.
    ' Get the Grid rows and build a Search index if requested.
    search = GetValueFromManifest("ALLOW_CHANNEL_SEARCH")
    if search = "true"
        gridRows = m.GridScreen.content.getChildren(- 1, 0)
        BuildContentIndex(gridRows)
    end if
    ' Get the input args to check for Deeplinking invocation.
    args = m.top.inputArgs
    ' If the args are valid, invoke Deeplinking.
    if args <> invalid and ValidateDeepLink(args)
        DeepLink(m.contentTask.content, args.dl_mediaType, args.dl_contentId)
    end if
end sub

'''''''''
' IsDuplicateIndexEntry: Checks for duplicate entries in the index that can result from playlists.
' 
' @param {object} I: _index - the content index.
' @param {string} I: _contentId - the content id to check for duplicates.
' @return {boolean} - returns true if duplicate, else, false.
'''''''''
function IsDuplicateIndexEntry(_index as object, _contentId as string) as boolean
    for each entry in _index
        if entry.id = _contentId
            return true
            exit for
        end if
    end for
    return false
end function

'''''''''
' BuildContentIndex: Builds the content index.
' 
' @param {object} I: _gridRows - the channel content from the Grid.
' @return {dynamic}
'''''''''
function BuildContentIndex(_gridRows as object)
    contentIndex = []
    for each gridRow in _gridRows
        ' Make sure the Grid row has content items.
        if gridRow.getChildCount() > 0
            ' Get the Grid row content items.
            rowChildren = gridRow.getChildren(- 1, 0)
            ' Create an index entry for each child item in the current Grid row.
            for each columnItem in rowChildren
                if IsDuplicateIndexEntry(contentIndex, columnItem.id) = false
                    if columnItem.mediaType <> "series"
                        description = (function(columnItem)
                                __bsConsequent = columnItem.longDescription
                                if __bsConsequent <> invalid then
                                    return __bsConsequent
                                else
                                    return columnItem.shortDescription
                                end if
                            end function)(columnItem)
                        indexEntry = {
                            id: columnItem.id
                            title: columnItem.title
                            desc: description
                            contentType: columnItem.mediaType
                            thumbnail: columnItem.hdPosterURL
                        }
                        contentIndex.Push(indexEntry)
                    else
                        ' Save the Series object.
                        description = (function(columnItem)
                                __bsConsequent = columnItem.longDescription
                                if __bsConsequent <> invalid then
                                    return __bsConsequent
                                else
                                    return columnItem.shortDescription
                                end if
                            end function)(columnItem)
                        indexEntry = {
                            id: columnItem.id
                            title: columnItem.title
                            desc: description
                            contentType: columnItem.mediaType
                            thumbnail: columnItem.hdPosterURL
                        }
                        contentIndex.Push(indexEntry)
                        ' Save the Episodes within a Season.
                        if columnItem.hasSeasons = true
                            seasons = columnItem.getChildren(- 1, 0)
                            for each season in seasons
                                episodes = season.getChildren(- 1, 0)
                                for each episode in episodes
                                    description = (function(columnItem)
                                            __bsConsequent = columnItem.longDescription
                                            if __bsConsequent <> invalid then
                                                return __bsConsequent
                                            else
                                                return columnItem.shortDescription
                                            end if
                                        end function)(columnItem)
                                    indexEntry = {
                                        id: episode.id
                                        title: episode.title
                                        desc: description
                                        contentType: episode.mediaType
                                        thumbnail: episode.hdPosterURL
                                    }
                                    contentIndex.Push(indexEntry)
                                end for
                            end for
                        else
                            ' Save the Episodes within a Series.
                            episodes = columnItem.getChildren(- 1, 0)
                            for each episode in episodes
                                description = (function(columnItem)
                                        __bsConsequent = columnItem.longDescription
                                        if __bsConsequent <> invalid then
                                            return __bsConsequent
                                        else
                                            return columnItem.shortDescription
                                        end if
                                    end function)(columnItem)
                                indexEntry = {
                                    id: episode.id
                                    title: episode.title
                                    desc: description
                                    contentType: episode.mediaType
                                    thumbnail: episode.hdPosterURL
                                }
                                contentIndex.Push(indexEntry)
                            end for
                        endif
                    end if
                end if
            end for
        end if
    end for
    ' Save the Search indices to the global node.
    m.global.addFields({
        "ContentIndex": contentIndex
    })
end function'//# sourceMappingURL=./ContentTaskLogic.bs.map